=======
History
=======

0.1.0 (2021-01-25)
------------------

* First release on PyPI.
* Implementation of basic CRUD methods (GET, UPDATE, DELETE, LIST), with json node normalization
* 100% code coverage in tests (TDD)
* Initial README and HISTORY

0.1.1 (2021-01-31)

* How to use basic adapter on in clean architecture projects.

0.1.3 (2021-11-10)

* Updating line length to flake8 tests
* Updating clean_architecture_basic_classes version, from 0.1.1 to 0.1.3
* Adjusting all code by according new line size

